#ifndef COMBINATORICS_H_
#define COMBINATORICS_H_

#include "mytypes.h"

void ksub_next ( int n, int k, IntVector& a, bool *more, int &m, int &m2);
void comp_next ( int n, int k, IntVector& a, bool *more, int &h, int &t );

#endif /*COMBINATORICS_H_*/
